﻿using System;
using System.Collections.Generic;
using TransitionSample.Common;
using TransitionSample.Models;
using TransitionSample.NavigationPages;
using TransitionSample.TransitionPages;
using Windows.ApplicationModel.Resources;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Navigation;

// The Pivot Application template is documented at http://go.microsoft.com/fwlink/?LinkID=391641

namespace TransitionSample
{
    public sealed partial class PivotPage : Page
    {
        private readonly NavigationHelper _navigationHelper;
        private readonly ResourceLoader _resourceLoader = ResourceLoader.GetForCurrentView("Resources");

        public PivotPage()
        {
            InitializeComponent();

            NavigationCacheMode = NavigationCacheMode.Required;

            _navigationHelper = new NavigationHelper(this);
            LoadTransitions();
        }

        public IEnumerable<TransitionItem> PageTransitions { get; set; }
        public IEnumerable<TransitionItem> ItemTransitions { get; set; }

        /// <summary>
        /// Gets the <see cref="NavigationHelper"/> associated with this <see cref="Page"/>.
        /// </summary>
        public NavigationHelper NavigationHelper
        {
            get { return this._navigationHelper; }
        }

        /// <summary>
        /// Invoked when an item within a section is clicked.
        /// </summary>
        private void ItemView_ItemClick(object sender, ItemClickEventArgs e)
        {
            // Navigate to the appropriate destination page, configuring the new page
            // by passing required information as a navigation parameter
            var item = (TransitionItem)e.ClickedItem;
            if (!Frame.Navigate(item.TransitionPage))
            {
                throw new Exception(this._resourceLoader.GetString("NavigationFailedExceptionMessage"));
            }
        }

        /// <summary>
        /// Loads all of the transitions and which page they go to
        /// </summary>
        private void LoadTransitions()
        {
            PageTransitions = new List<TransitionItem>
            {
                new TransitionItem {Title = "Continuum transition",TransitionPage = typeof (ContinuumNavigationFirstPage)},
                new TransitionItem {Title = "Feather transition", TransitionPage = typeof (FeatherNavigationPage)},
                new TransitionItem {Title = "Tiled Feather transition", TransitionPage = typeof (TileFeatherNavigationPage)},
                new TransitionItem {Title = "Slide transition", TransitionPage = typeof (SlideNavigationPage)},
                new TransitionItem {Title = "Edge transition",TransitionPage = typeof (EdgeTransitionFirstPage)},
                new TransitionItem {Title = "Complex transition",TransitionPage = typeof (ComplexTransitionPage)},
                new TransitionItem {Title = "Partial transition",TransitionPage = typeof (PartialTransitionFirstPage)},
            };
            ItemTransitions = new List<TransitionItem>
            {
                new TransitionItem {Title = "Slide in", TransitionPage = typeof (SlideInTransitionPage)},
                new TransitionItem {Title = "Add/Delete item", TransitionPage = typeof (AddDeleteTransitionPage)},
                new TransitionItem {Title = "Reorder item", TransitionPage = typeof (ReorderTransitionPage)},
                new TransitionItem {Title = "Tilt", TransitionPage = typeof (TiltAnimationPage)},
            };
        }


        #region NavigationHelper registration

        /// <summary>
        /// The methods provided in this section are simply used to allow
        /// NavigationHelper to respond to the page's navigation methods.
        /// <para>
        /// Page specific logic should be placed in event handlers for the  
        /// <see cref="NavigationHelper.LoadState"/>
        /// and <see cref="NavigationHelper.SaveState"/>.
        /// The navigation parameter is available in the LoadState method 
        /// in addition to page state preserved during an earlier session.
        /// </para>
        /// </summary>
        /// <param name="e">Provides data for navigation methods and event
        /// handlers that cannot cancel the navigation request.</param>
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            this._navigationHelper.OnNavigatedTo(e);
        }

        protected override void OnNavigatedFrom(NavigationEventArgs e)
        {
            this._navigationHelper.OnNavigatedFrom(e);
        }

        #endregion
    }
}
